@@ -1,7 +1,5 @@
-#!/usr/bin/perl -w
-#
-
-package Element;
+package # put package name on different line to skip pause indexing
+    Element;
 
 use strict;
 use warnings;
